@@ -1,6 +1,8 @@
 #!/bin/bash -xe
 # script to get tarball(s) from Jenkins
 
+KAMEL_VERSION="1.3.1" # see https://github.com/redhat-developer/codeready-workspaces-deprecated/blob/master/kamel/build.sh#L16 or https://github.com/apache/camel-k/releases
+
 scratchFlag=""
 JOB_BRANCH=""
 doRhpkgContainerBuild=1
@@ -56,10 +58,7 @@ if [[ ! $jenkinsURL ]]; then
 	echo "[ERROR] Cannot resolve artifact(s) for this build. Must abort!"
 	exit 1
 fi
-lastSuccessfulURL="${jenkinsURL}/lastSuccessfulBuild/api/xml?xpath=//" # id or description
-
-KUBECTL_VERSION="v1.18.10" # see https://github.com/kubernetes/kubernetes/releases/ or $(curl -s https://storage.googleapis.googleapis.com/kubernetes-release/release/stable.txt)
-KAMEL_VERSION="1.2.1" # see https://github.com/redhat-developer/codeready-workspaces-deprecated/blob/master/kamel/build.sh#L16 or https://github.com/apache/camel-k/releases
+lastSuccessfulURL="${jenkinsURL}/lastSuccessfulBuild/api/xml?xpath=/workflowRun/" # id
 
 jenkinsURL=${jenkinsURL}/lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/kamel/target
 
@@ -90,11 +89,10 @@ if [[ ${outputFiles} ]]; then
   log "[INFO] Upload new sources: ${outputFiles}"
   rhpkg new-sources ${outputFiles}
   log "[INFO] Commit new sources from: ${outputFiles}"
-	ID=$(curl -L -s -S ${lastSuccessfulURL}${field} | \
-		sed -e "s#<${field}>\(.\+\)</${field}>#\1#" -e "s#&lt;br/&gt; #\n#g" -e "s#\&lt;a.\+/a\&gt;##g")
+	field=id; ID=$(curl -L -s -S ${lastSuccessfulURL}${field} | sed -e "s#<${field}>\(.\+\)</${field}>#\1#" -e "s#&lt;br/&gt; #\n#g" -e "s#\&lt;a.\+/a\&gt;##g")
 	if [[ $(echo $ID | grep -E "404 Not Found|ERROR 404|Application is not available") ]]; then 
 		echo $ID
-		echo "[ERROR] Problem loading ID from $lastSuccessfulURL :: NOT FOUND!"
+		echo "[ERROR] Problem loading ID from ${lastSuccessfulURL}${field} :: NOT FOUND!"
 		exit 1;
 	fi
   COMMIT_MSG="Update from Jenkins :: kamel ${KAMEL_VERSION} from ${UPSTREAM_JOB_NAME} :: ${ID}
